<div class="well well-small">
    <h3>Image Registry tool:</h3>
    <br />
    <p>
        Image Registry is used to provide additional information about images for Savanna
    </p>
    <p>
        Specified username will be used by Savanna to apply configs and manage processes on instances.
    </p>
    <p>
        Tags are used for filtering images suitable for each plugin and each hadoop version.
        To add required tags, select a plugin with Hadoop version and click &quotAdd all&quot button.
    </p>
    <p>
        You may also add any custom tag.
    </p>
    <p>
        Unnecessary tags may be removed by clicking a cross near tag's name.
    </p>
</div>