{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Savanna" %}{% endblock %}

{% block page_header %}
    {% include "horizon/common/_page_header.html" with title=_("Savanna - Image Registry") %}
{% endblock page_header %}

{% block main %}

<div class="image_registry">
    {{ image_registry_table.render }}
</div>

{% endblock %}