{% extends 'base.html' %}
{% load i18n sizeformat %}
{% block title %}{% trans "Nodegroup Template Details" %}{% endblock %}

{% block page_header %}
    {% include "horizon/common/_page_header.html" with title=_("Savanna node group template details") %}
{% endblock page_header %}

{% block main %}
    <div class="row-fluid">
        <div class="span12">
            {{ tab_group.render }}
        </div>
    </div>
{% endblock %}