{% extends 'base.html' %}
{% load i18n sizeformat %}
{% block title %}{% trans "Plugin Detail" %}{% endblock %}

{% block page_header %}
    {% include "horizon/common/_page_header.html" with title=_("Savanna Plugin Details") %}
{% endblock page_header %}

{% block main %}
<div class="row-fluid">
    <div class="span12">
        {{ tab_group.render }}
    </div>
</div>
{% endblock %}