{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Register Image" %}{% endblock %}

{% block page_header %}
    {% include "horizon/common/_page_header.html" with title=_("Register Image") %}
{% endblock page_header %}

{% block main %}
    {% include 'templates/image_registry/_register_image.html' %}
{% endblock %}