{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block form_id %}register_image_form{% endblock %}
{% block form_action %}{% url horizon:savanna:image_registry:register %}{% endblock %}

{% block modal-header %}{% trans "Register Image" %}{% endblock %}

{% block modal-body %}
    <div class="left">
        <fieldset>
            {% include "horizon/common/_form_fields.html" %}
            {% include 'image_registry/_tag_form.html' %}
        </fieldset>
    </div>
    <div class="right">
        {% include 'image_registry/_help.html' %}
    </div>
{% endblock %}

{% block modal-footer %}
    <input class="btn btn-primary pull-right" id="edit_image_tags_btn" type="submit" value="{% trans " Done" %}"/>
    <a href="{% url horizon:savanna:image_registry:index %}" class="btn secondary cancel close">{% trans "Cancel" %}</a>
{% endblock %}